@@ -6,13 +6,15 @@ import unittest
 import subprocess
 import urllib
 import traceback
+import shutil
 from time import sleep
 
 sys.path.insert(0, '.')
 sys.path.insert(0, '../')
 sys.path.insert(0, '../../')
-import LendingClubInvestor
+from LendingClubInvestor import util
 from LendingClubInvestor import AutoInvestor
+from LendingClubInvestor.settings import Settings
 
 
 class TestInvestorUtils(unittest.TestCase):
@@ -31,46 +33,46 @@ class TestInvestorUtils(unittest.TestCase):
 
     def test_prompt(self):
         # User enters 'test'
-        self.investor.get_input = lambda msg: 'test'
-        self.assertEqual(self.investor.prompt('msg'), 'test')
-        self.assertEqual(self.investor.prompt('msg', 'not test'), 'test')
+        util.get_input = lambda msg: 'test'
+        self.assertEqual(util.prompt('msg'), 'test')
+        self.assertEqual(util.prompt('msg', 'not test'), 'test')
 
     def test_prompt_prefill(self):
         # User enters empty string, select prefill
-        self.investor.get_input = lambda msg: ''
-        self.assertEqual(self.investor.prompt('msg'), '')
-        self.assertEqual(self.investor.prompt('msg', 'not test'), 'not test')
+        util.get_input = lambda msg: ''
+        self.assertEqual(util.prompt('msg'), '')
+        self.assertEqual(util.prompt('msg', 'not test'), 'not test')
 
     def test_prompt_yn(self):
         # Yes
-        self.investor.get_input = lambda msg: 'y'
-        self.assertTrue(self.investor.prompt_yn('msg'))
-        self.investor.get_input = lambda msg: 'Y'
-        self.assertTrue(self.investor.prompt_yn('msg'))
-        self.investor.get_input = lambda msg: 'Yes'
-        self.assertTrue(self.investor.prompt_yn('msg'))
+        util.get_input = lambda msg: 'y'
+        self.assertTrue(util.prompt_yn('msg'))
+        util.get_input = lambda msg: 'Y'
+        self.assertTrue(util.prompt_yn('msg'))
+        util.get_input = lambda msg: 'Yes'
+        self.assertTrue(util.prompt_yn('msg'))
 
         # No
-        self.investor.get_input = lambda msg: 'n'
-        self.assertFalse(self.investor.prompt_yn('msg'))
-        self.investor.get_input = lambda msg: 'N'
-        self.assertFalse(self.investor.prompt_yn('msg'))
-        self.investor.get_input = lambda msg: 'No'
-        self.assertFalse(self.investor.prompt_yn('msg'))
+        util.get_input = lambda msg: 'n'
+        self.assertFalse(util.prompt_yn('msg'))
+        util.get_input = lambda msg: 'N'
+        self.assertFalse(util.prompt_yn('msg'))
+        util.get_input = lambda msg: 'No'
+        self.assertFalse(util.prompt_yn('msg'))
 
         # Invalid user input
         def get_input(msg):
             self.count += 1
             return 'Hi' if self.count == 1 else 'Y'
-        self.investor.get_input = get_input
-        self.assertTrue(self.investor.prompt_yn('msg'))
+        util.get_input = get_input
+        self.assertTrue(util.prompt_yn('msg'))
         self.assertEqual(self.count, 2)
 
     def test_prompt_yn_prefill(self):
         # User enters empty string, select prefill
-        self.investor.get_input = lambda msg: ''
-        self.assertTrue(self.investor.prompt_yn('msg', 'y'))
-        self.assertFalse(self.investor.prompt_yn('msg', 'n'))
+        util.get_input = lambda msg: ''
+        self.assertTrue(util.prompt_yn('msg', 'y'))
+        self.assertFalse(util.prompt_yn('msg', 'n'))
 
     def test_prompt_float(self):
         self.count = 0
@@ -85,18 +87,18 @@ class TestInvestorUtils(unittest.TestCase):
             else:
                 return '10.0'
 
-        self.investor.get_input = get_input
-        self.assertEqual(self.investor.prompt_float('msg'), 10.0)
+        util.get_input = get_input
+        self.assertEqual(util.prompt_float('msg'), 10.0)
         self.assertEqual(self.count, 3)
 
         # Values with commas
-        self.investor.get_input = lambda msg: '1,000.1'
-        self.assertEqual(self.investor.prompt_float('msg'), 1000.1)
+        util.get_input = lambda msg: '1,000.1'
+        self.assertEqual(util.prompt_float('msg'), 1000.1)
 
     def test_prompt_float_prefill(self):
         # User enters empty string, select prefill
-        self.investor.get_input = lambda msg: ''
-        self.assertEqual(self.investor.prompt_float('msg', 10.1), 10.1)
+        util.get_input = lambda msg: ''
+        self.assertEqual(util.prompt_float('msg', 10.1), 10.1)
 
     def test_prompt_int(self):
 
@@ -110,36 +112,36 @@ class TestInvestorUtils(unittest.TestCase):
             else:
                 return '10'
 
-        self.investor.get_input = get_input
-        self.assertEqual(self.investor.prompt_float('msg'), 10)
+        util.get_input = get_input
+        self.assertEqual(util.prompt_float('msg'), 10)
         self.assertEqual(self.count, 3)
 
         # Values with commas
-        self.investor.get_input = lambda msg: '1,000.1'
-        self.assertEqual(self.investor.prompt_float('msg'), 1000.1)
+        util.get_input = lambda msg: '1,000.1'
+        self.assertEqual(util.prompt_float('msg'), 1000.1)
 
     def test_prompt_int_prefill(self):
         # User enters empty string, select prefill
-        self.investor.get_input = lambda msg: ''
-        self.assertEqual(self.investor.prompt_int('msg', 15), 15)
+        util.get_input = lambda msg: ''
+        self.assertEqual(util.prompt_int('msg', 15), 15)
 
     def test_is_float(self):
-        self.assertTrue(self.investor.isfloat('10'))
-        self.assertTrue(self.investor.isfloat('11.5'))
-        self.assertTrue(self.investor.isfloat('-13'))
-        self.assertTrue(self.investor.isfloat(14.5))
+        self.assertTrue(util.isfloat('10'))
+        self.assertTrue(util.isfloat('11.5'))
+        self.assertTrue(util.isfloat('-13'))
+        self.assertTrue(util.isfloat(14.5))
 
-        self.assertFalse(self.investor.isfloat('NotANumber'))
-        self.assertFalse(self.investor.isfloat('PartNumber123'))
+        self.assertFalse(util.isfloat('NotANumber'))
+        self.assertFalse(util.isfloat('PartNumber123'))
 
     def test_currency_to_number(self):
-        self.assertStrictEqual(self.investor.currency_to_float('123.45'), 123.45)
-        self.assertStrictEqual(self.investor.currency_to_float('$123.45'), 123.45)
-        self.assertStrictEqual(self.investor.currency_to_float('123.45$'), 123.45)
-        self.assertStrictEqual(self.investor.currency_to_float('123.45$USD'), 123.45)
-        self.assertStrictEqual(self.investor.currency_to_float('1,230.45'), 1230.45)
-        self.assertStrictEqual(self.investor.currency_to_float('123'), 123.0)
-        self.assertStrictEqual(self.investor.currency_to_float('$123'), 123.0)
+        self.assertStrictEqual(util.currency_to_float('123.45'), 123.45)
+        self.assertStrictEqual(util.currency_to_float('$123.45'), 123.45)
+        self.assertStrictEqual(util.currency_to_float('123.45$'), 123.45)
+        self.assertStrictEqual(util.currency_to_float('123.45$USD'), 123.45)
+        self.assertStrictEqual(util.currency_to_float('1,230.45'), 1230.45)
+        self.assertStrictEqual(util.currency_to_float('123'), 123.0)
+        self.assertStrictEqual(util.currency_to_float('$123'), 123.0)
 
 
 class TestInvestorFlow(unittest.TestCase):
@@ -147,6 +149,7 @@ class TestInvestorFlow(unittest.TestCase):
 
     server = None
     investor = None
+    settings = None
 
     def startNode(self):
         """ Start the node server, if it's not already running """
@@ -168,22 +171,28 @@ class TestInvestorFlow(unittest.TestCase):
 
     def setUp(self):
         # Start dummy server
+        util.baseUrl = 'http://localhost:7357'
         self.startNode()
 
-        # Create investor object
-        self.investor = AutoInvestor()
-        self.investor.baseUrl = 'http://localhost:7357'
-        self.investor.settings_file = os.path.join(os.path.dirname(os.path.realpath(__file__)), '.investortest')
-        self.investor.settings = {
+        logger = TestLogger()
+        base_dir = os.path.dirname(os.path.realpath(__file__))
+
+        # Create investor objects
+        self.settings = Settings(settings_dir=os.path.join(base_dir, 'testsettings'), logger=logger)
+        self.settings.auth = {
             'email': 'test@test.com',
-            'pass': 'testpassword',
+            'pass': 'testpassword'
+        }
+        self.settings.investing = {
             'minCash': 100,
             'minPercent': 16.5,
             'maxPercent': 19.0,
             'portfolio': 'Existing Portfolio',
             'filters': False
         }
-        self.investor.logger = TestLogger()
+        self.investor = AutoInvestor(settings=self.settings)
+        self.investor.app_dir = base_dir
+        self.investor.logger = logger
 
     def tearDown(self):
         # Stop node
@@ -191,12 +200,12 @@ class TestInvestorFlow(unittest.TestCase):
             self.server.kill()
 
         # Delete settings file
-        if os.path.exists(self.investor.settings_file):
-            os.remove(self.investor.settings_file)
+        if os.path.exists(self.settings.settings_dir):
+            shutil.rmtree(self.settings.settings_dir)
 
     def set_default_filters(self):
         """ Sets all the filters to default valeus (True) """
-        self.investor.settings['filters'] = {
+        self.settings.investing['filters'] = {
             'exclude_existing': True,
             'term36month': True,
             'term60month': True,
@@ -215,18 +224,18 @@ class TestInvestorFlow(unittest.TestCase):
     def set_filters(self):
         """ Add advanced filtering to the investor settings """
         self.set_default_filters()
-        self.investor.settings['filters']['term36month'] = False
-        self.investor.settings['filters']['grades']['All'] = False
-        self.investor.settings['filters']['grades']['D'] = False
-        self.investor.settings['filters']['grades']['E'] = False
-        self.investor.settings['filters']['grades']['F'] = False
-        self.investor.settings['filters']['grades']['G'] = False
+        self.settings.investing['filters']['term36month'] = False
+        self.settings.investing['filters']['grades']['All'] = False
+        self.settings.investing['filters']['grades']['D'] = False
+        self.settings.investing['filters']['grades']['E'] = False
+        self.settings.investing['filters']['grades']['F'] = False
+        self.settings.investing['filters']['grades']['G'] = False
 
     def test_login(self):
         self.assertTrue(self.investor.authenticate())
 
     def test_invalid_login(self):
-        self.investor.settings['email'] = 'wrong@wrong.com'
+        self.settings.auth['email'] = 'wrong@wrong.com'
         self.assertFalse(self.investor.authenticate())
 
     def test_get_cash_balance(self):
@@ -244,7 +253,7 @@ class TestInvestorFlow(unittest.TestCase):
 
     def test_investment_option_minimums(self):
         """ Test min percent: no investment options between 18.7 - 19.0 """
-        self.investor.settings['minPercent'] = 18.7
+        self.settings.investing['minPercent'] = 18.7
         match = self.investor.get_investment_option(200)
         self.assertFalse(match)
 
@@ -269,8 +278,8 @@ class TestInvestorFlow(unittest.TestCase):
         The server is expecting A,B,C and should raise an error if it sees anything else"""
 
         self.set_filters()
-        self.investor.settings['filters']['grades']['All'] = True
-        self.investor.settings['filters']['grades']['G'] = True
+        self.settings.investing['filters']['grades']['All'] = True
+        self.settings.investing['filters']['grades']['G'] = True
         match = self.investor.get_investment_option(200)
 
         # Check for error
@@ -283,8 +292,8 @@ class TestInvestorFlow(unittest.TestCase):
         The server should raise an error for invalid JSON"""
 
         # Create a request with bad JSON
-        formerFilterFunc = LendingClubInvestor.get_filter_json
-        LendingClubInvestor.get_filter_json = lambda settings: '{invalid json feed,,}'
+        formerFilterFunc = util.get_filter_json
+        util.get_filter_json = lambda settings: '{invalid json feed,,}'
         match = self.investor.get_investment_option(200)
 
         # Check for error
@@ -292,7 +301,7 @@ class TestInvestorFlow(unittest.TestCase):
         self.assertEqual(len(self.investor.logger.errors), 1)
 
         # Reset
-        LendingClubInvestor.get_filter_json = formerFilterFunc
+        util.get_filter_json = formerFilterFunc
 
     def test_investment_option_filters_within_percent(self):
         """ Investment Options within percent settings.
@@ -301,8 +310,8 @@ class TestInvestorFlow(unittest.TestCase):
         self.set_filters()
 
         # Default min/max are 16.5 - 19.0, filtered results fixture only goes up to 15.03
-        self.investor.settings['minPercent'] = 13.0
-        self.investor.settings['maxPercent'] = 14.5
+        self.settings.investing['minPercent'] = 13.0
+        self.settings.investing['maxPercent'] = 14.5
         match = self.investor.get_investment_option(200)
         self.assertEqual(match['percentage'], 14.5)  # should be a perfect match
 
@@ -318,20 +327,20 @@ class TestInvestorFlow(unittest.TestCase):
         # Set C to False, everything else true
         self.set_default_filters()
         self.assertTrue(self.investor.validate_option(match))  # defaults should be True
-        self.investor.settings['filters']['grades']['All'] = False
-        self.investor.settings['filters']['grades']['C'] = False
+        self.settings.investing['filters']['grades']['All'] = False
+        self.settings.investing['filters']['grades']['C'] = False
         self.assertFalse(self.investor.validate_option(match))  # False
 
         # Set 36 month to False, everything else true
         self.set_default_filters()
         self.assertTrue(self.investor.validate_option(match))  # defaults should be True
-        self.investor.settings['filters']['term36month'] = False
+        self.settings.investing['filters']['term36month'] = False
         self.assertFalse(self.investor.validate_option(match))  # False
 
         # Set 60 month to False, everything else true
         self.set_default_filters()
         self.assertTrue(self.investor.validate_option(match))  # defaults should be True
-        self.investor.settings['filters']['term60month'] = False
+        self.settings.investing['filters']['term60month'] = False
         self.assertFalse(self.investor.validate_option(match))  # False
 
     def test_prepare_order(self):
@@ -359,7 +368,7 @@ class TestInvestorFlow(unittest.TestCase):
     def test_assign_to_porfolio_new(self):
         """ Assign to a new portfolio """
 
-        self.investor.settings['portfolio'] = 'New Porfolio'
+        self.settings.investing['portfolio'] = 'New Porfolio'
         ret = self.investor.assign_to_portfolio(orderID=123, loanIDs=[456], returnJson=True)
         self.assertEqual(ret['result'], 'success')
         self.assertEqual(ret['portfolioName'], 'New Portfolio')  # hard coded in the JSON response
@@ -375,7 +384,7 @@ class TestInvestorFlow(unittest.TestCase):
         should still return True, but add a warning to the log. (easy to test, since the mock
         server returns hard coded JSON) """
 
-        self.investor.settings['portfolio'] = 'A Folio'  # server will respond with 'New Portfolio'
+        self.settings.investing['portfolio'] = 'A Folio'  # server will respond with 'New Portfolio'
         ret = self.investor.assign_to_portfolio(orderID=123, loanIDs=[456])
         self.assertTrue(ret)
 
@@ -395,7 +404,7 @@ class TestInvestorFlow(unittest.TestCase):
 
     def test_assign_to_porfolio_no_portfolio(self):
         """ Test if not assigning to porfolio assign_to_portfolio() should return True """
-        self.investor.settings['portfolio'] = False
+        self.settings.investing['portfolio'] = False
         ret = self.investor.assign_to_portfolio(orderID=123, loanIDs=[456])
         self.assertTrue(ret)
 
@@ -415,7 +424,7 @@ class TestInvestorFlow(unittest.TestCase):
 
     def test_attempt_to_invest_no_folio(self):
         """ Test end-to-end investment without portfolio """
-        self.investor.settings['portfolio'] = False
+        self.settings.investing['portfolio'] = False
         ret = self.investor.attempt_to_invest()
         self.assertTrue(ret)
 
@@ -425,7 +434,7 @@ class TestInvestorFlow(unittest.TestCase):
 
     def test_attempt_to_invest_not_enough_cash(self):
         """ Test end-to-end investment without portfolio """
-        self.investor.settings['minCash'] = 1000
+        self.settings.investing['minCash'] = 1000
         ret = self.investor.attempt_to_invest()
         self.assertFalse(ret)
 
@@ -436,7 +445,7 @@ class TestInvestorFlow(unittest.TestCase):
     def test_attempt_to_invest_no_option_match(self):
         """ Test end-to-end investment without investment option match """
         # No options between 18.7 - 19.0
-        self.investor.settings['minPercent'] = 18.7
+        self.settings.investing['minPercent'] = 18.7
         ret = self.investor.attempt_to_invest()
         self.assertFalse(ret)
 
